@@ -4,9 +4,9 @@ mod jobs_test;
 
 use crate::models::common::*;
 use crate::models::problem::{Costs, Fleet, TransportCost};
+use crate::utils::as_mut;
 use hashbrown::HashMap;
 use rosomaxa::prelude::compare_floats;
-use std::cell::UnsafeCell;
 use std::cmp::Ordering::Less;
 use std::hash::{Hash, Hasher};
 use std::sync::{Arc, Weak};
@@ -132,18 +132,18 @@ impl JobPermutation for FixedJobPermutation {
 impl Multi {
     /// Creates a new multi job from given 'dimens' and `jobs` assuming that jobs has to be
     /// inserted in order they specified.
-    pub fn new(jobs: Vec<Arc<Single>>, dimens: Dimensions) -> Self {
+    pub fn new_shared(jobs: Vec<Arc<Single>>, dimens: Dimensions) -> Arc<Self> {
         let permutations = vec![(0..jobs.len()).collect()];
-        Self { jobs, dimens, permutator: Box::new(FixedJobPermutation::new(permutations)) }
+        Self::bind(Self { jobs, dimens, permutator: Box::new(FixedJobPermutation::new(permutations)) })
     }
 
     /// Creates a new multi job from given 'dimens' and `jobs` using `permutator` to control insertion order.
-    pub fn new_with_permutator(
+    pub fn new_shared_with_permutator(
         jobs: Vec<Arc<Single>>,
         dimens: Dimensions,
         permutator: Box<dyn JobPermutation + Send + Sync>,
-    ) -> Self {
-        Self { jobs, dimens, permutator }
+    ) -> Arc<Self> {
+        Self::bind(Self { jobs, dimens, permutator })
     }
 
     /// Returns all sub-jobs permutations.
@@ -160,31 +160,21 @@ impl Multi {
         self.permutator.validate(permutations)
     }
 
-    /// Wraps given multi job into [`Arc`] adding reference to it from all sub-jobs.
-    pub fn bind(multi: Self) -> Arc<Self> {
-        // NOTE: layout must be identical
-        #[allow(dead_code)]
-        struct SingleConstruct {
-            pub places: UnsafeCell<Vec<Place>>,
-            pub dimens: UnsafeCell<Dimensions>,
-        }
-
-        let multi = Arc::new(multi);
-
-        multi.jobs.iter().for_each(|job| {
-            let weak_multi = Arc::downgrade(&multi);
-            let job: Arc<SingleConstruct> = unsafe { std::mem::transmute(job.clone()) };
-            let dimens = unsafe { &mut *job.dimens.get() };
-            dimens.set_value("rf", weak_multi);
-        });
-
-        multi
-    }
-
     /// Returns parent multi job for given sub-job.
     pub fn roots(single: &Single) -> Option<Arc<Multi>> {
         single.dimens.get_value::<Weak<Multi>>("rf").and_then(|w| w.upgrade())
     }
+
+    /// Wraps given multi job into [`Arc`] adding reference to it from all sub-jobs.
+    fn bind(multi: Self) -> Arc<Self> {
+        Arc::new_cyclic(|weak_multi| {
+            multi.jobs.iter().for_each(|job| {
+                unsafe { as_mut(job.as_ref()) }.dimens.set_value("rf", weak_multi.clone());
+            });
+
+            multi
+        })
+    }
 }
 
 type JobIndex = HashMap<Job, (Vec<(Job, Cost)>, HashMap<Job, Cost>, Cost)>;
