@@ -4,6 +4,7 @@ use crate::models::common::SingleDimLoad;
 use crate::models::problem::ProblemObjective;
 use crate::rosomaxa::get_default_selection_size;
 use crate::solver::search::*;
+use rosomaxa::algorithms::gsom::Input;
 use rosomaxa::hyper::*;
 use rosomaxa::population::*;
 use rosomaxa::termination::*;
@@ -49,10 +50,13 @@ pub type TargetHeuristicGroup = HeuristicGroup<RefinementContext, ProblemObjecti
 pub type ProblemConfigBuilder = EvolutionConfigBuilder<RefinementContext, ProblemObjective, InsertionContext, String>;
 
 /// Creates config builder with default settings.
-pub fn create_default_config_builder(problem: Arc<Problem>, environment: Arc<Environment>) -> ProblemConfigBuilder {
+pub fn create_default_config_builder(
+    problem: Arc<Problem>,
+    environment: Arc<Environment>,
+    telemetry_mode: TelemetryMode,
+) -> ProblemConfigBuilder {
     let selection_size = get_default_selection_size(environment.as_ref());
     let population = get_default_population(problem.objective.clone(), environment.clone(), selection_size);
-    let telemetry_mode = get_default_telemetry_mode(environment.logger.clone());
 
     ProblemConfigBuilder::default()
         .with_heuristic(get_default_heuristic(problem.clone(), environment.clone()))
@@ -68,10 +72,7 @@ pub fn get_default_telemetry_mode(logger: InfoLogger) -> TelemetryMode {
 
 /// Gets default heuristic.
 pub fn get_default_heuristic(problem: Arc<Problem>, environment: Arc<Environment>) -> TargetHeuristic {
-    Box::new(MultiSelective::<RefinementContext, ProblemObjective, InsertionContext>::new(
-        get_dynamic_heuristic(problem.clone(), environment.clone()),
-        get_static_heuristic(problem, environment),
-    ))
+    get_dynamic_heuristic(problem, environment)
 }
 
 /// Gets static heuristic using default settings.
@@ -120,8 +121,8 @@ pub fn create_elitism_population(objective: Arc<ProblemObjective>, environment:
 }
 
 impl RosomaxaWeighted for InsertionContext {
-    fn weights(&self) -> Vec<f64> {
-        vec![
+    fn init_weights(&mut self) {
+        let weights = vec![
             get_max_load_variance(self),
             get_duration_mean(self),
             get_distance_mean(self),
@@ -133,7 +134,14 @@ impl RosomaxaWeighted for InsertionContext {
             get_longest_distance_between_depot_customer_mean(self),
             self.solution.routes.len() as f64,
             self.solution.unassigned.len() as f64,
-        ]
+        ];
+        self.solution.state.insert(SOLUTION_WEIGHTS_KEY, Arc::new(weights));
+    }
+}
+
+impl Input for InsertionContext {
+    fn weights(&self) -> &[f64] {
+        self.solution.state.get(&SOLUTION_WEIGHTS_KEY).and_then(|s| s.downcast_ref::<Vec<f64>>()).unwrap().as_slice()
     }
 }
 
@@ -258,6 +266,7 @@ mod statik {
 
         // initialize ruin
         let close_route = Arc::new(CloseRouteRemoval::default());
+        let worst_route = Arc::new(WorstRouteRemoval::default());
         let random_route = Arc::new(RandomRouteRemoval::default());
         let random_job = Arc::new(RandomJobRemoval::new(RuinLimits::default()));
         let random_ruin = create_default_random_ruin();
@@ -274,6 +283,7 @@ mod statik {
                 5,
             ),
             (vec![(close_route, 1.), (random_job.clone(), 0.1)], 2),
+            (vec![(worst_route, 1.), (random_job.clone(), 0.1)], 1),
             (vec![(random_route, 1.), (random_job, 0.1)], 1),
         ]));
 
@@ -288,6 +298,7 @@ mod statik {
         Arc::new(WeightedRuin::new(vec![
             (vec![(Arc::new(CloseRouteRemoval::default()), 1.)], 100),
             (vec![(Arc::new(RandomRouteRemoval::default()), 1.)], 10),
+            (vec![(Arc::new(WorstRouteRemoval::default()), 1.)], 5),
             (vec![(Arc::new(RandomJobRemoval::new(RuinLimits::default())), 1.)], 2),
         ]))
     }
@@ -350,18 +361,18 @@ mod dynamic {
         let primary_ruins: Vec<(Arc<dyn Ruin + Send + Sync>, String)> = vec![
             (Arc::new(AdjustedStringRemoval::default()), "asr".to_string()),
             (Arc::new(NeighbourRemoval::default()), "neighbour_removal".to_string()),
-            (Arc::new(WorstJobRemoval::default()), "worst_job".to_string()),
             (
                 Arc::new(ClusterRemoval::new_with_defaults(problem.clone(), environment.clone())),
                 "cluster_removal".to_string(),
             ),
+            (Arc::new(WorstJobRemoval::default()), "worst_job".to_string()),
             (Arc::new(RandomJobRemoval::new(RuinLimits::default())), "random_job_removal_1".to_string()),
             (Arc::new(RandomRouteRemoval::default()), "random_route_removal".to_string()),
-        ];
-        let secondary_ruins: Vec<(Arc<dyn Ruin + Send + Sync>, String)> = vec![
             (Arc::new(CloseRouteRemoval::default()), "close_route_removal".to_string()),
-            (Arc::new(RandomJobRemoval::new(RuinLimits::new(2, 8, 0.1, 2))), "random_job_removal_2".to_string()),
+            (Arc::new(WorstRouteRemoval::default()), "worst_route_removal".to_string()),
         ];
+        let secondary_ruins: Vec<(Arc<dyn Ruin + Send + Sync>, String)> =
+            vec![(Arc::new(RandomJobRemoval::new(RuinLimits::new(2, 8, 0.1, 2))), "random_job_removal_2".to_string())];
 
         // NOTE we need to wrap any of ruin methods in composite which calls restore context before recreate
         let ruins = primary_ruins
