@@ -102,6 +102,7 @@ use rosomaxa::evolution::*;
 use rosomaxa::prelude::*;
 use rosomaxa::{get_default_population, DynHeuristicPopulation, TelemetryHeuristicContext};
 use std::any::Any;
+use std::ops::Deref;
 use std::sync::Arc;
 
 pub use self::heuristic::*;
@@ -116,6 +117,8 @@ mod heuristic;
 
 /// A key to store solution order information.
 const SOLUTION_ORDER_KEY: i32 = 1;
+/// A key to store solution weights information.
+const SOLUTION_WEIGHTS_KEY: i32 = 2;
 
 /// Keys for balancing objectives.
 const BALANCE_MAX_LOAD_KEY: i32 = 20;
@@ -251,14 +254,16 @@ impl InitialOperator for RecreateInitialOperator {
 ///
 /// ```
 /// # use vrp_core::models::examples::create_example_problem;
+/// # use vrp_core::solver::get_default_telemetry_mode;
 /// # use std::sync::Arc;
 /// use vrp_core::prelude::*;
 ///
 /// // create your VRP problem
 /// let problem: Arc<Problem> = create_example_problem();
 /// let environment = Arc::new(Environment::new_with_time_quota(Some(60)));
+/// let telemetry_mode = get_default_telemetry_mode(environment.logger.clone());
 /// // build solver config using pre-build builder with defaults and then override some parameters
-/// let config = create_default_config_builder(problem.clone(), environment)
+/// let config = create_default_config_builder(problem.clone(), environment, telemetry_mode)
 ///     .with_max_time(Some(60))
 ///     .with_max_generations(Some(100))
 ///     .build()?;
@@ -288,6 +293,12 @@ impl Solver {
     /// Solves a Vehicle Routing Problem and returns a _(solution, its cost)_ pair in case of success
     /// or error description, if solution cannot be found.
     pub fn solve(self) -> Result<(Solution, Cost, Option<TelemetryMetrics>), String> {
+        self.config.context.environment.logger.deref()(&format!(
+            "total jobs: {}, actors: {}",
+            self.problem.jobs.size(),
+            self.problem.fleet.actors.len()
+        ));
+
         let (mut solutions, metrics) = EvolutionSimulator::new(self.config)?.run()?;
 
         // NOTE select the first best individual from population
