@@ -28,8 +28,8 @@ impl Objective for TotalRoutes {
     type Solution = InsertionContext;
 
     fn total_order(&self, a: &Self::Solution, b: &Self::Solution) -> Ordering {
-        let fitness_a = a.solution.routes.len() as f64;
-        let fitness_b = b.solution.routes.len() as f64;
+        let fitness_a = self.fitness(a);
+        let fitness_b = self.fitness(b);
 
         let (fitness_a, fitness_b) =
             if self.is_minimization { (fitness_a, fitness_b) } else { (-1. * fitness_a, -1. * fitness_b) };
