@@ -1,6 +1,6 @@
 use super::*;
-use crate::construction::constraints::{StrictLockingModule, TransportConstraintModule};
-use crate::helpers::construction::constraints::create_simple_demand;
+use crate::construction::constraints::*;
+use crate::helpers::construction::constraints::{create_simple_demand, create_simple_dynamic_demand};
 use crate::helpers::models::problem::*;
 use crate::models::common::*;
 use crate::models::problem::*;
@@ -9,7 +9,7 @@ use crate::models::{Lock, LockDetail, LockOrder, LockPosition, Problem};
 use rosomaxa::prelude::Environment;
 
 type JobData = (Option<Location>, (f64, f64), Duration, i32);
-type VehicleData = ((Location, Option<f64>, Option<f64>), Option<(Location, Option<f64>, Option<f64>)>);
+type VehicleData = (i32, (Location, Option<f64>, Option<f64>), Option<(Location, Option<f64>, Option<f64>)>);
 type ActivityData = (Location, Duration, (Timestamp, Timestamp), Arc<Single>);
 type RouteData<'a> = Vec<(&'a str, Location, Duration, (Timestamp, Timestamp), usize)>;
 type LockData<'a> = (&'a str, LockOrder, LockPosition, Vec<&'a str>);
@@ -20,28 +20,28 @@ fn create_test_problem(
     vehicles: Vec<(&str, VehicleData)>,
     locks: Vec<LockData>,
 ) -> Problem {
-    let create_single = |id: &str, (location, (tw_start, tw_end), duration, demand)| {
+    let create_single = |id: &str, (location, (tw_start, tw_end), duration, demand), is_multi| {
         SingleBuilder::default()
             .id(id)
             .location(location)
             .duration(duration)
             .times(vec![TimeWindow::new(tw_start, tw_end)])
-            .demand(create_simple_demand(demand))
+            .demand(if is_multi { create_simple_dynamic_demand(demand) } else { create_simple_demand(demand) })
             .build()
     };
 
     let jobs = singles
         .into_iter()
-        .map(|(id, data)| Job::Single(Arc::new(create_single(id, data))))
+        .map(|(id, data)| Job::Single(Arc::new(create_single(id, data, false))))
         .chain(multies.into_iter().map(|(id, singles)| {
-            let singles = singles.into_iter().map(|data| Arc::new(create_single(id, data))).collect();
+            let singles = singles.into_iter().map(|data| Arc::new(create_single(id, data, true))).collect();
             Job::Multi(test_multi_with_id(id, singles))
         }))
         .collect::<Vec<_>>();
 
     let vehicles = vehicles
         .into_iter()
-        .map(|(id, ((start_location, start_earliest, start_latest), end))| {
+        .map(|(id, (capacity, (start_location, start_earliest, start_latest), end))| {
             VehicleBuilder::default()
                 .id(id)
                 .details(vec![VehicleDetail {
@@ -54,6 +54,7 @@ fn create_test_problem(
                         time: TimeInterval { earliest: end_earliest, latest: end_latest },
                     }),
                 }])
+                .capacity(capacity)
                 .build()
         })
         .collect::<Vec<_>>();
@@ -88,6 +89,11 @@ fn create_test_problem(
         3,
     )));
     constraint.add_module(Arc::new(StrictLockingModule::new(&fleet, locks.as_slice(), 4)));
+    constraint.add_module(Arc::new(CapacityConstraintModule::<SingleDimLoad>::new(
+        activity.clone(),
+        transport.clone(),
+        5,
+    )));
 
     Problem {
         fleet: fleet.clone(),
@@ -185,30 +191,29 @@ parameterized_test! {can_restore_solution, (singles, mutlies, locks, vehicles, r
 }}
 
 can_restore_solution! {
-
     case01_single_all_correct: (vec![("job1", (Some(1), (1., 3.), 1., 1)), ("job2", (Some(2), (2., 4.), 1., 1)), ("job3", (Some(3), (3., 5.), 1., 1))],
         vec![], vec![],
-        vec![("v1", ((0, Some(0.), None), Some((0, None, Some(10.)))))],
+        vec![("v1", (10, (0, Some(0.), None), Some((0, None, Some(10.)))))],
         vec![("v1", vec![ ("job1", 1, 1., (1., 3.), 0), ("job2", 2, 1., (2., 4.), 0), ("job3", 3, 1., (3., 5.), 0)])],
         ((0, 0), vec![("v1", vec!["job1", "job2", "job3"])])),
 
     case02_single_invalid_second_job_tw: (vec![("job1", (Some(1), (1., 3.), 1., 1)), ("job2", (Some(2), (0., 1.), 1., 1)), ("job3", (Some(3), (3., 5.), 1., 1))],
         vec![], vec![],
-        vec![("v1", ((0, Some(0.), None), Some((0, None, Some(10.)))))],
+        vec![("v1", (10, (0, Some(0.), None), Some((0, None, Some(10.)))))],
         vec![("v1", vec![ ("job1", 1, 1., (1., 3.), 0), ("job2", 2, 1., (0., 1.), 0), ("job3", 3, 1., (3., 5.), 0)])],
         ((1, 0), vec![("v1", vec!["job1", "job3"])])),
 
     case03_single_multi_assignment_in_one_route: (vec![("job1", (Some(1), (0., 10.), 1., 1)), ("job2", (Some(2), (0., 10.), 1., 1))],
         vec![], vec![],
-        vec![("v1", ((0, Some(0.), None), Some((0, None, Some(10.)))))],
+        vec![("v1", (10, (0, Some(0.), None), Some((0, None, Some(10.)))))],
         vec![("v1", vec![ ("job1", 1, 1., (0., 10.), 0), ("job2", 2, 1., (0., 10.), 0), ("job2", 2, 1., (0., 10.), 0)])],
         ((0, 0), vec![("v1", vec!["job1", "job2"])])),
 
     case04_single_multi_assignment_in_different_routes: (vec![("job1", (Some(1), (0., 10.), 1., 1)), ("job2", (Some(2), (0., 10.), 1., 1))],
         vec![], vec![],
         vec![
-            ("v1", ((0, Some(0.), None), Some((0, None, Some(10.))))),
-            ("v2", ((0, Some(0.), None), Some((0, None, Some(10.))))),
+            ("v1", (10, (0, Some(0.), None), Some((0, None, Some(10.))))),
+            ("v2", (10, (0, Some(0.), None), Some((0, None, Some(10.))))),
         ],
         vec![
             ("v1", vec![ ("job1", 1, 1., (0., 10.), 0), ("job2", 2, 1., (0., 10.), 0)]),
@@ -219,49 +224,49 @@ can_restore_solution! {
     case05_multi_all_correct: (vec![],
         vec![("job1", vec![(Some(1), (1., 3.), 1., 1),  (Some(2), (2., 4.), 1., 1), (Some(3), (3., 5.), 1., 1)])],
         vec![],
-        vec![("v1", ((0, Some(0.), None), Some((0, None, Some(10.)))))],
+        vec![("v1", (10, (0, Some(0.), None), Some((0, None, Some(10.)))))],
         vec![("v1", vec![ ("job1", 1, 1., (1., 3.), 0), ("job1", 2, 1., (2., 4.), 1), ("job1", 3, 1., (3., 5.), 2)])],
         ((0, 0), vec![("v1", vec!["job1", "job1", "job1"])])),
 
     case06_multi_invalid_second_index: (vec![],
         vec![("job1", vec![(Some(1), (1., 3.), 1., 1),  (Some(2), (2., 4.), 1., 1), (Some(3), (3., 5.), 1., 1)])],
         vec![],
-        vec![("v1", ((0, Some(0.), None), Some((0, None, Some(10.)))))],
+        vec![("v1", (10, (0, Some(0.), None), Some((0, None, Some(10.)))))],
         vec![("v1", vec![ ("job1", 1, 1., (1., 3.), 0), ("job1", 2, 1., (2., 4.), 0), ("job1", 3, 1., (3., 5.), 2)])],
         ((1, 0), vec![])),
 
     case07_multi_partial_assignment: (vec![],
         vec![("job1", vec![(Some(1), (1., 3.), 1., 1),  (Some(2), (2., 4.), 1., 1), (Some(3), (3., 5.), 1., 1)])],
         vec![],
-        vec![("v1", ((0, Some(0.), None), Some((0, None, Some(10.)))))],
+        vec![("v1", (10, (0, Some(0.), None), Some((0, None, Some(10.)))))],
         vec![("v1", vec![ ("job1", 1, 1., (1., 3.), 0),  ("job1", 2, 1., (2., 4.), 1), ])],
         ((1, 0), vec![])),
 
     case08_multi_invalid_permutation: (vec![],
         vec![("job1", vec![(Some(1), (0., 10.), 1., 1), (Some(2), (0., 10.), 1., 1)])],
         vec![],
-        vec![("v1", ((0, Some(0.), None), Some((0, None, Some(10.)))))],
+        vec![("v1", (10, (0, Some(0.), None), Some((0, None, Some(10.)))))],
         vec![("v1", vec![ ("job1", 2, 1., (0., 10.), 1), ("job1", 1, 1., (0., 10.), 0)])],
         ((1, 0), vec![])),
 
     case09_relation_all_correct: (vec![("job1", (Some(1), (1., 3.), 1., 1)), ("job2", (Some(2), (2., 4.), 1., 1)), ("job3", (Some(3), (3., 5.), 1., 1))],
         vec![],
         vec![("v1", LockOrder::Sequence, LockPosition::Departure, vec!["job1", "job2"])],
-        vec![("v1", ((0, Some(0.), None), Some((0, None, Some(10.)))))],
+        vec![("v1", (10, (0, Some(0.), None), Some((0, None, Some(10.)))))],
         vec![("v1", vec![ ("job1", 1, 1., (1., 3.), 0), ("job2", 2, 1., (2., 4.), 0), ("job3", 3, 1., (3., 5.), 0)])],
         ((0, 0), vec![("v1", vec!["job1", "job2", "job3"])])),
 
     case10_relation_sequence_middle: (vec![("job1", (Some(1), (0., 10.), 1., 1)), ("job2", (Some(2), (0., 10.), 1., 1)), ("job3", (Some(3), (0., 10.), 1., 1))],
         vec![],
         vec![("v1", LockOrder::Sequence, LockPosition::Departure, vec!["job1", "job2"])],
-        vec![("v1", ((0, Some(0.), None), Some((0, None, Some(10.)))))],
+        vec![("v1", (10, (0, Some(0.), None), Some((0, None, Some(10.)))))],
         vec![("v1", vec![ ("job1", 1, 1., (0., 10.), 0), ("job3", 3, 1., (0., 10.), 0), ("job2", 2, 1., (0., 10.), 0)])],
         ((0, 0), vec![("v1", vec!["job1", "job2", "job3"])])),
 
     case11_relation_strict_end: (vec![("job1", (Some(1), (0., 10.), 1., 1)), ("job2", (Some(2), (0., 10.), 1., 1)), ("job3", (Some(3), (0., 10.), 1., 1))],
         vec![],
         vec![("v1", LockOrder::Strict, LockPosition::Arrival, vec!["job1", "job2"])],
-        vec![("v1", ((0, Some(0.), None), Some((0, None, Some(10.)))))],
+        vec![("v1", (10, (0, Some(0.), None), Some((0, None, Some(10.)))))],
         vec![("v1", vec![ ("job1", 1, 1., (0., 10.), 0), ("job3", 3, 1., (0., 10.), 0), ("job2", 2, 1., (0., 10.), 0)])],
         ((1, 0), vec![("v1", vec!["job1", "job2"])])),
 
@@ -269,14 +274,35 @@ can_restore_solution! {
         vec![],
         vec![("v2", LockOrder::Strict, LockPosition::Arrival, vec!["job1", "job2"])],
         vec![
-            ("v1", ((0, Some(0.), None), Some((0, None, Some(10.))))),
-            ("v2", ((0, Some(0.), None), Some((0, None, Some(10.)))))
+            ("v1", (10, (0, Some(0.), None), Some((0, None, Some(10.))))),
+            ("v2", (10, (0, Some(0.), None), Some((0, None, Some(10.)))))
         ],
         vec![
             ("v1", vec![ ("job1", 1, 1., (0., 10.), 0), ("job3", 3, 1., (0., 10.), 0), ("job2", 2, 1., (0., 10.), 0)]),
             ("v2", vec![ ("job1", 1, 1., (0., 10.), 0), ("job2", 2, 1., (0., 10.), 0), ("job3", 3, 1., (0., 10.), 0)])
         ],
         ((0, 0), vec![("v1", vec!["job3"]), ("v2", vec!["job1", "job2"])])),
+
+    case13_multi_job_early_rejection: (vec![],
+        vec![
+            ("job1", vec![(Some(1), (0., 100.), 0., 1), (Some(2), (0., 100.), 0., -1)]),
+            ("job2", vec![(Some(3), (0., 100.), 0., 2), (Some(4), (0., 100.), 0., -2)]),
+            ("job3", vec![(Some(5), (0., 100.), 0., 2), (Some(6), (0., 100.), 0., -2)])
+        ],
+        vec![],
+        vec![("v1", (2, (0, Some(0.), None), Some((0, None, Some(100.)))))],
+        vec![
+            ("v1", vec![
+                ("job1", 1, 0., (0., 100.), 0),
+                ("job2", 3, 0., (0., 100.), 0),
+                ("job2", 4, 0., (0., 100.), 1),
+                ("job3", 5, 0., (0., 100.), 0),
+                ("job3", 6, 0., (0., 100.), 1),
+                ("job1", 2, 0., (0., 100.), 1)
+            ]),
+        ],
+        ((2, 0), vec![("v1", vec!["job1", "job1"])]),
+    ),
 }
 
 fn can_restore_solution_impl(
@@ -297,9 +323,9 @@ fn can_restore_solution_impl(
     });
 
     let ((unassigned, required), routes) = expected;
+    assert_eq!(get_routes(&result), routes);
     assert_eq!(result.solution.unassigned.len(), unassigned);
     assert_eq!(result.solution.required.len(), required);
-    assert_eq!(get_routes(&result), routes);
 }
 
 // TODO:
